==> artyom.js-0.9.5.tgz: package/README.md <==
![Artyom Logo](https://raw.githubusercontent.com/sdkcarlos/artyom.js/master/src/images/artyomjs-logo.png)

## Latest news
##[Read the official documentation of Artyom](http://ourcodeworld.com/projects/projects-documentation/1/list/artyom-js)
##[Read the official FAQ](http://ourcodeworld.com/projects/projects-faq/1/list/artyom-js)
##[Test the continuous mode here](https://sdkcarlos.github.io/jarvis.html)

The user of artyom is encouraged to use its latest version.

- **Artyom V 0.9.5 Released ! (31.05.2016 14:45 Berlin/Europe)**
- Artyom V 0.9.2 Released ! (10.05.2016 19:46 Berlin/Europe)

Voice recognition javascript library. Create your own siri,google now or cortana within your website.

Artyom still in constantly update.
visit the webpage for more info:
It's recomendable to download always the latest version of artyom anyway check the changes in order to update from a previous version.

###Who does not want to develop their own "artificial intelligence"? Well Artyom can help you with a Voice Controlled Web!

<p align="center">
  <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/artyom_make_sandwich.jpg" alt="Artyom example use"/>
</p>

## Demostrations
###[Homepage](http://sdkcarlos.github.io/sites/artyom.html)
###[JARVIS Continuous mode](https://sdkcarlos.github.io/jarvis.html)
###[Sticky Notes Demo ALL Languages](https://sdkcarlos.github.io/demo-sites/artyom/artyom_sticky_notes.html)

#Installation

You can get it on npm.

```shell
npm install artyom.js
```

And bower.

```shell
bower install artyom.js
```
Or download a zip package here [Download .zip](https://github.com/sdkcarlos/artyom.js/raw/master/public/artyom-source.zip)

You need more functions, methods for this library ? Just ask for it ! in issues section

#[Ask for a method , problems, questions etc ...](https://github.com/sdkcarlos/artyom.js/issues)
#[Open Wiki (tutorial, documentation)](http://ourcodeworld.com/projects/projects-documentation/1/list/artyom-js)
#[See changelog](http://ourcodeworld.com/projects/projects-documentation/2/read-doc/official-changelog/artyom-js)

Artyom offers **COMPLETE** Support for the following languages

| |Description |Codes for initialization|
------------- | ------------- | ------------- |
|<img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-usa.png" alt="Supported language"/>| English (USA)<br/>English (Great Britain) Great Britain <br/> United States of America | en-US<br/>en-GB<br/>en |
|<img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-spanish.png" alt="Supported language"/>| Español |es-CO<br/>es-ES<br/>es |
|<img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-german.png" alt="Supported language"/>| Deutsch | de-DE<br/>de |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-italy.png" alt="Supported language"/> | Italiano |it-IT |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-france.png" alt="Supported language"/> | Français |fr-FR<br/>fr |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-japan.png" alt="Supported language"/> | Japanese 日本人 | ja-JP<br/>jp |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-russia.png" alt="Supported language"/> | Russian | ru-RU<br/>ru |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-brasil.png" alt="Supported language"/> | Brazil | pt-PT<br/>pt |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-netherlands.png" alt="Supported language"/> | Dutch (netherlands)| nl-NL<br/>nl |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-poland.png" alt="Supported language"/> | Polski (polonia)| pl-PL<br/>pl |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-indonesia.png" alt="Supported language"/> | Indonesian (Indonesia)| id-ID<br/>id |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-china.png" alt="Supported language"/> | Chinese (Cantonese[ 粤語（香港）] <br/> Mandarin[普通话（中国大陆）])| Cantonese<br/>zh-HK<br/> Mandarin<br />zh-CN|

==> artyom.js-0.9.6.tgz: package/README.md <==
<p align="center">
  <img src="https://raw.githubusercontent.com/sdkcarlos/artyom.js/master/src/images/artyomjs-logo.png" width="256" title="Artyom logo">
</p>

## Latest news
##[Read the official documentation of Artyom](http://ourcodeworld.com/projects/projects-documentation/1/list/artyom-js)
##[Read the official FAQ](http://ourcodeworld.com/projects/projects-faq/1/list/artyom-js)
##[Test the continuous mode here](https://sdkcarlos.github.io/jarvis.html)

The user of artyom is encouraged to use its latest version.

- **Artyom V 0.9.6 Released ! (06.06.2016 10:08 Berlin/Europe)**
- Artyom V 0.9.5 Released ! (31.05.2016 14:45 Berlin/Europe)
- Artyom V 0.9.2 Released ! (10.05.2016 19:46 Berlin/Europe)

Voice recognition javascript library. Create your own siri,google now or cortana within your website.

Artyom is constantly maintained and updated with new gadgets. It's recomendable to download always the latest version of artyom anyway check the changes in order to update from a previous version.

###Who does not want to develop their own "artificial intelligence"? Well Artyom can help you with a Voice Controlled Web!

<p align="center">
  <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/artyom_make_sandwich.jpg" alt="Artyom example use" width="256"/>
</p>

## Demonstrations
###[Homepage](http://sdkcarlos.github.io/sites/artyom.html)
###[JARVIS Continuous mode](https://sdkcarlos.github.io/jarvis.html)
###[Sticky Notes Demo ALL Languages](https://sdkcarlos.github.io/demo-sites/artyom/artyom_sticky_notes.html)

#Installation

You can get it on npm.

```shell
npm install artyom.js
```

And bower.

```shell
bower install artyom.js
```
Or download a zip package here [Download .zip](https://github.com/sdkcarlos/artyom.js/raw/master/public/artyom-source.zip)

Do you need more functions, methods for this library ? Just ask for it ! in issues section

#[Ask for a method , problems, questions etc ...](https://github.com/sdkcarlos/artyom.js/issues)
#[Open Wiki (tutorial, documentation)](http://ourcodeworld.com/projects/projects-documentation/1/list/artyom-js)
#[See changelog](http://ourcodeworld.com/projects/projects-documentation/2/read-doc/official-changelog/artyom-js)

Artyom offers **COMPLETE** Support for the following languages

| |Description |Codes for initialization|
------------- | ------------- | ------------- |
|<img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-usa.png" alt="Supported language"/>| English (USA)<br/>English (Great Britain) Great Britain <br/> United States of America | en-US<br/>en-GB<br/>en |
|<img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-spanish.png" alt="Supported language"/>| Español |es-CO<br/>es-ES<br/>es |
|<img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-german.png" alt="Supported language"/>| Deutsch | de-DE<br/>de |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-italy.png" alt="Supported language"/> | Italiano |it-IT |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-france.png" alt="Supported language"/> | Français |fr-FR<br/>fr |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-japan.png" alt="Supported language"/> | Japanese 日本人 | ja-JP<br/>jp |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-russia.png" alt="Supported language"/> | Russian | ru-RU<br/>ru |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-brasil.png" alt="Supported language"/> | Brazil | pt-PT<br/>pt |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-netherlands.png" alt="Supported language"/> | Dutch (netherlands)| nl-NL<br/>nl |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-poland.png" alt="Supported language"/> | Polski (polonia)| pl-PL<br/>pl |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-indonesia.png" alt="Supported language"/> | Indonesian (Indonesia)| id-ID<br/>id |
| <img src="https://raw.githubusercontent.com/sdkcarlos/sdkcarlos.github.io/master/sites/artyom-resources/images/flag-china.png" alt="Supported language"/> | Chinese (Cantonese[ 粤語（香港）] <br/> Mandarin[普通话（中国大陆）])| Cantonese<br/>zh-HK<br/> Mandarin<br />zh-CN|
